Welcome to Orange3 Text Mining documentation!
=============================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/corpus-widget
   widgets/importdocuments
   widgets/createcorpus
   widgets/guardian-widget
   widgets/nytimes
   widgets/pubmed
   widgets/twitter-widget
   widgets/wikipedia-widget
   widgets/preprocesstext
   widgets/bagofwords-widget
   widgets/documentembedding
   widgets/similarityhashing
   widgets/sentimentanalysis
   widgets/tweetprofiler
   widgets/topicmodelling-widget
   widgets/LDAvis
   widgets/corpusviewer
   widgets/wordcloud
   widgets/concordance
   widgets/docmap
   widgets/wordenrichment
   widgets/duplicatedetection
   widgets/statistics
   widgets/corpustonetwork
   widgets/keywords
   widgets/score-documents
   widgets/semanticviewer
   widgets/collocations
   widgets/wordlist
   widgets/ontology

Scripting
---------

.. toctree::
   :maxdepth: 2

   scripting/corpus.rst
   scripting/preprocess.rst
   scripting/twitter.rst
   scripting/nyt.rst
   scripting/guardian.rst
   scripting/wikipedia.rst
   scripting/bagofwords.rst
   scripting/topicmodeling.rst
   scripting/tag.rst
   scripting/async.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

